@@ -11,8 +11,8 @@ use MooseX::Singleton;
 use WiX3::Util::StrictConstructor;
 use WiX3::Trace::Object;
 
-our $VERSION = '0.008';
-$VERSION = eval $VERSION; ## no critic(ProhibitStringyEval)
+our $VERSION = '0.009';
+$VERSION =~ s/_//ms;
 
 with 'WiX3::Role::Traceable';
 
@@ -26,7 +26,18 @@ sub BUILDARGS {
 		%args = (@_);
 	}
 
-	return { options => WiX3::Trace::Object->new(%args) };
+	##no critic ( RequireCarping RequireUseOfExceptions ProtectPrivateSubs )
+	my $obj;
+	eval {
+		$obj = WiX3::Trace::Object->new(%args);
+		1;
+	} || eval {
+		WiX3::Trace::Object->_clear_instance();
+		$obj = WiX3::Trace::Object->new(%args);
+		1;
+	} || die 'Could not create trace object';
+
+	return { options => $obj };
 } ## end sub BUILDARGS
 
 sub BUILD {
@@ -48,7 +59,7 @@ WiX3::Traceable - "Cheat Class" in order to initialize a Traceable object.
 
 =head1 VERSION
 
-This document describes WiX3::Traceable version 0.005
+This document describes WiX3::Traceable version 0.009
 
 =head1 SYNOPSIS
 
@@ -92,14 +103,14 @@ Curtis Jewell  C<< <csjewell@cpan.org> >>
 
 =head1 SEE ALSO
 
-L<Exception::Class>
+L<Exception::Class|Exception::Class>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2009, Curtis Jewell C<< <csjewell@cpan.org> >>. All rights reserved.
+Copyright 2009, 2010 Curtis Jewell C<< <csjewell@cpan.org> >>.
 
 This module is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself. See L<perlartistic>.
+modify it under the same terms as Perl 5.8.1 itself. See L<perlartistic|perlartistic>.
 
 
 =head1 DISCLAIMER OF WARRANTY
