@@ -14,8 +14,8 @@ use WiX3::Util::StrictConstructor;
 use Params::Util qw( _IDENTIFIER _STRING );
 use File::Spec::Functions qw( catdir );
 
-our $VERSION = '0.007';
-$VERSION = eval $VERSION; ## no critic(ProhibitStringyEval)
+our $VERSION = '0.009';
+$VERSION =~ s/_//ms;
 
 with qw(WiX3::XML::Role::TagAllowsChildTags
   WiX3::XML::Role::GeneratesGUID
@@ -231,7 +231,7 @@ WiX3::XML::Directory - Class representing a Directory tag.
 
 =head1 VERSION
 
-This document describes WiX3::XML::Directory version 0.005
+This document describes WiX3::XML::Directory version 0.009
 
 =head1 SYNOPSIS
 
@@ -252,7 +252,8 @@ All attributes are lowercased when passed as a parameter.
 
 =head1 INTERFACE 
 
-This class implementes all methods of the L<XML::WiX3::Classes::Role::Tag> role.
+This class implementes all methods of the 
+L<XML::WiX3::Classes::Role::Tag|XML::WiX3::Classes::Role::Tag> role.
 
 =head2 Other parameters to new
 
@@ -305,10 +306,10 @@ L<http://wix.sourceforge.net/manual-wix3/wix_xsd_directory.htm>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2009, Curtis Jewell C<< <csjewell@cpan.org> >>. All rights reserved.
+Copyright 2009, 2010 Curtis Jewell C<< <csjewell@cpan.org> >>.
 
 This module is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself. See L<perlartistic>.
+modify it under the same terms as Perl 5.8.1 itself. See L<perlartistic|perlartistic>.
 
 
 =head1 DISCLAIMER OF WARRANTY
