@@ -13,11 +13,12 @@ use MooseX::Types::Moose qw( Str Maybe );
 use WiX3::Types qw( YesNoType );
 use WiX3::Util::StrictConstructor;
 
-our $VERSION = '0.007';
-$VERSION = eval $VERSION; ## no critic(ProhibitStringyEval)
+our $VERSION = '0.009';
+$VERSION =~ s/_//ms;
 
 # http://wix.sourceforge.net/manual-wix3/wix_xsd_featureref.htm
 
+with 'WiX3::XML::Role::Tag';
 with 'WiX3::XML::Role::TagAllowsChildTags';
 
 ## Allows Component, ComponentGroupRef, ComponentRef, Feature,
@@ -79,7 +80,7 @@ sub as_string {
 	$answer = '<FeatureRef';
 	$answer .= $self->print_attribute( 'Id', $id );
 	$answer .=
-	  $self->print_attribute( 'IgnoreParent', $self->_ignoreparent() );
+	  $self->print_attribute( 'IgnoreParent', $self->_get_ignoreparent() );
 	$answer .= " />\n";
 
 	return $answer;
@@ -102,7 +103,7 @@ WiX3::XML::FeatureRef - Defines a FeatureRef tag.
 
 =head1 VERSION
 
-This document describes WiX3::XML::FeatureRef version 0.005
+This document describes WiX3::XML::FeatureRef version 0.009
 
 =head1 SYNOPSIS
 
@@ -147,10 +148,10 @@ L<http://wix.sourceforge.net/>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2009, Curtis Jewell C<< <csjewell@cpan.org> >>. All rights reserved.
+Copyright 2009, 2010 Curtis Jewell C<< <csjewell@cpan.org> >>.
 
 This module is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself. See L<perlartistic>.
+modify it under the same terms as Perl 5.8.1 itself. See L<perlartistic|perlartistic>.
 
 
 =head1 DISCLAIMER OF WARRANTY
