@@ -12,8 +12,8 @@ use Params::Util qw( _STRING  );
 use MooseX::Types::Moose qw( Str );
 use WiX3::Util::StrictConstructor;
 
-our $VERSION = '0.007';
-$VERSION = eval $VERSION; ## no critic(ProhibitStringyEval)
+our $VERSION = '0.009';
+$VERSION =~ s/_//ms;
 
 # http://wix.sourceforge.net/manual-wix3/wix_xsd_icon.htm
 
@@ -79,7 +79,7 @@ WiX3::XML::Icon - Defines a Icon tag.
 
 =head1 VERSION
 
-This document describes WiX3::XML::Icon version 0.005
+This document describes WiX3::XML::Icon version 0.009
 
 =head1 SYNOPSIS
 
@@ -124,10 +124,10 @@ L<http://wix.sourceforge.net/>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2009, Curtis Jewell C<< <csjewell@cpan.org> >>. All rights reserved.
+Copyright 2009, 2010 Curtis Jewell C<< <csjewell@cpan.org> >>.
 
 This module is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself. See L<perlartistic>.
+modify it under the same terms as Perl 5.8.1 itself. See L<perlartistic|perlartistic>.
 
 
 =head1 DISCLAIMER OF WARRANTY
